program

Function program 

pub fn program(target: &Target) -> Vec<Insn>
Builds the filter program for target.

Allowed syscall numbers are merged into contiguous ranges; each range is three instructions with only short forward jumps, so the program needs no jump longer than the 255 instructions BPF allows.