pub fn missing_syscalls(kernel: KernelVersion, allow: &[&str]) -> Vec<Syscall>Expand description
Syscalls missing from kernel, minus any names in allow (backports).
pub fn missing_syscalls(kernel: KernelVersion, allow: &[&str]) -> Vec<Syscall>Syscalls missing from kernel, minus any names in allow (backports).