pub fn table_ceiling() -> KernelVersionExpand description
The newest release scanned for the data (from its # Tags scanned:
header), which can be newer than the last release that added a syscall.
pub fn table_ceiling() -> KernelVersionThe newest release scanned for the data (from its # Tags scanned:
header), which can be newer than the last release that added a syscall.